# -*- coding: utf-8 -*-

from django.utils.importlib import import_module
from django.conf import settings
from logging import getLogger
logger = getLogger('default')


class CoopBar:
    __we_all_are_one = {}

    def __init__(self):
        self.__dict__ = self.__we_all_are_one  # Borg pattern

        if not self.__dict__:  # Don't reload for each instance
            self._callbacks = []
            self._headers = []
            self._footer = []
            coop_bar_modules = getattr(settings, 'COOP_BAR_MODULES', ['coop_cms.coop_bar_cfg'])

            # manual loading : just follow the settings

            for module_name in coop_bar_modules:
                #print 'trying to load : ' + module_name + '...'
                try:
                    toolbar_module = import_module(module_name)
                    loader_fct = getattr(toolbar_module, 'load_commands')
                    #print 'trying to load ' + str(loader_fct) + '...'
                    loader_fct(self)
                    #print 'toolbar links from ' + module_name + ' loaded!'

                except ImportError, e:
                    raise ImportError(u"coop_bar : error loading %s. Check COOP_BAR_MODULES in settings \n %s" % (module_name,e))

            # automatic mode : looking for some coop_bar_cfg modules

            # not yet usable until we have a real way to order collected commands (ex: with a "weight" parameter)
            # else:
            #     for app in settings.INSTALLED_APPS:
            #         try:
            #             #load dynamically the admin_bar module of all apps
            #             app_admin_bar_module = import_module(app + '.coop_bar_cfg')
            #             if hasattr(app_admin_bar_module, 'load_commands'):
            #                 #call the load_commands function in this module
            #                 #This function should call the AdminBar:register_command for
            #                 #every item it want to insert in the bar
            #                 loader_fct = getattr(app_admin_bar_module, 'load_commands')
            #                 loader_fct(self)
            #         except ImportError:
            #             pass

    def register_header(self, callback):
        self._headers.append(callback)

    def register_footer(self, callback):
        self._footer.append(callback)

    def register_command(self, callback):
        self._callbacks.append(callback)

    def register_separator(self):
        self._callbacks.append(None)

    def register(self, list_of_list_of_cmds):
        for list_of_cmds in list_of_list_of_cmds:
            for callback in list_of_cmds:
                self.register_command(callback)
            self.register_separator()

    def get_commands(self, request, context):
        commands = []
        separator = '<div class="separator"></div>'
        for c in self._callbacks:
            if c == None:
                #Replace None by separator. Avoid 2 following separators
                if commands and commands[-1] != separator:
                    html = separator
                else:
                    html = ''
            else:
                #when a page wants to display the admin_bar
                #calls the registred callback in order to know what to display
                html = c(request, context)
            if html:
                commands.append(html)
        if commands and commands[-1] == separator:
            commands = commands[:-1]
        return commands

    def get_headers(self, request, context):
        headers = []
        for c in self._headers:
            html = c(request, context)
            if html:
                headers.append(html)
        return headers

    def get_footer(self, request, context):
        footer = []
        for c in self._footer:
            html = c(request, context)
            if html:
                footer.append(html)
        return footer




# -*- coding: utf-8 -*-

from django import template
from django.template.loader import get_template
from django.utils.translation import ugettext as _
from django.template import Context
register = template.Library()
from coop_bar.bar import CoopBar
from django.conf import settings
STATIC_URL = getattr(settings, 'STATIC_URL', '')
from coop_bar import settings as bar_settings
from logging import getLogger


class CoopBarNode(template.Node):
    def render(self, context):
        request = context.get("request", None)
        commands = CoopBar().get_commands(request, context)
        if commands:  # hide admin-bar if nothing to display
            t = get_template("coop_bar.html")
            return t.render(Context({'commands': commands}))
        return u''


@register.tag
def coop_bar(parser, token):
    return CoopBarNode()


class CoopBarHeaderNode(template.Node):
    def render(self, context):
        request = context.get("request", None)
        headers = [u'<link rel="stylesheet" href="%scss/coop_bar.css" type="text/css" />' % STATIC_URL]
        headers += [u'<script type="text/javascript" src="%sjs/jquery-ui-1.8.14.custom.min.js"></script>' % STATIC_URL]
        # ajout des librairies nécessaires à colorbox
        headers += [u'<script type="text/javascript" charset="utf-8" src="%sjs/jquery.colorbox-min.js"></script>' % STATIC_URL]
        headers += [u'<script type="text/javascript" charset="utf-8" src="%sjs/jquery.form.js"></script>' % STATIC_URL]
        headers += [u'<script type="text/javascript" src="%sjs/colorbox.coop.js"></script>' % STATIC_URL]
        headers += [u'<script type="text/javascript" src="%sjs/jquery.pageslide.js"></script>' % STATIC_URL]
        headers += [u'<link rel="stylesheet" href="%scss/colorbox.css" type="text/css" />' % STATIC_URL]
        if 'messages' in context:
            headers += [u'<script type="text/javascript" src="%sjs/jquery.humanmsg.js"></script>' % STATIC_URL]
            headers += [u'<script type="text/javascript" src="%sjs/jquery.easing.1.3.js"></script>' % STATIC_URL]
        headers += CoopBar().get_headers(request, context)
        return "\n".join(headers)


@register.tag
def coop_bar_headers(parser, token):
    return CoopBarHeaderNode()


class CoopBarFooterNode(template.Node):
    def render(self, context):
        request = context.get("request", None)
        footer = [u'''
<script type="text/javascript">
$(document).ready(function(){
        ''']
        footer += [u'''
    $("#coop-bar").draggable();
    $("a.colorbox-form").colorboxify({
        close_popup_and_media_slide: function() {
            $.colorbox.close();
            $("#coopbar_medialibrary").click();
        }
    });
        ''']

        # messages framework display

        logger = getLogger('default')
        from django.contrib import messages
        msg_list = messages.get_messages(request)

        if msg_list:
            from django.template.defaultfilters import escapejs
            for m in msg_list:
                logger.debug(unicode(m))
                footer += [u'''
    humanMsg.displayMsg("''' + escapejs(unicode(m)) + u'''", "''' + unicode(m.tags) + u'''");
                ''']
            if len(msg_list) > 1 or bar_settings.DISPLAY_MESSAGES_LOG:
                footer += [u'''
    $("#humanMsgLog p").show();
                ''']

        footer += CoopBar().get_footer(request, context)  # TODO profiler cette méthode (cache ?)
        footer += [u'''
});
</script>''']
        return "\n".join(footer)


@register.tag
def coop_bar_footer(parser, token):
    return CoopBarFooterNode()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

try:
    from setuptools import setup, find_packages
except ImportError:
    import ez_setup
    ez_setup.use_setuptools()
    from setuptools import setup, find_packages

VERSION = __import__('coop_bar').__version__

import os
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name ='coop-bar',
    version = VERSION,
    description ='Pluggable admin bar system , works well with coop-cms',
    long_description = open('README.rst').read(),
    packages = ['coop_bar','coop_bar.templatetags'],
    include_package_data = True,
    author = 'Luc Jean',
    author_email = 'ljean@apidev.fr',
    license ='BSD',
    url = "https://github.com/quinode/coop-bar/",
    download_url = "https://github.com/quinode/coop-bar/tarball/master",
    zip_safe = False,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
        'Natural Language :: English',
        'Natural Language :: French',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],
)




# -*- coding: utf-8 -*-

from django.conf import settings

def make_link(url, label, icon, id=None, classes=None):
    icon_url = settings.STATIC_URL+icon
    
    extra_args = [u'id="{0}"'.format(id)] if id else []
    if classes:
        extra_args += [u'class="{0}"'.format(u' '.join(classes))]
        
    return u'<a href="{url}" style="background-image:url({icon_url})"{args}>{label}</a>'.format(
        url=url, icon_url=icon_url, args=u' '.join(extra_args), label=label
    )

